"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var hornet_js_utils_1 = require("hornet-js-utils");
var logger_1 = require("hornet-js-logger/src/logger");
var CLS_KEY = "hornet.timers";
var Timer = /** @class */ (function () {
    function Timer() {
    }
    /**
     * Démarre un timer et en arrête un autre s'il est renseigné.
     * @param {string} timerName id du timer à démarrer
     * @param {string}  stopTimerName id du timer à arrêter
     */
    Timer.startTimer = function (timerName, stopTimerName) {
        var timers = Timer.getTimers();
        if (!timers) {
            timers = {};
        }
        if (!timers[timerName]) {
            timers[timerName] = [];
        }
        if (timers[timerName].length % 2 !== 0) {
            Timer.logger.debug("startTimer : Probl\u00E8me de Timers (" + timerName + ") non stopp\u00E9.");
        }
        else {
            timers[timerName].push(new Date().getTime());
            Timer.setTimers(timers);
        }
        if (stopTimerName) {
            Timer.stopTimer(stopTimerName);
        }
    };
    /**
     * Arrête un timer
     * @param {string} timerName id du timer à démarrer
     */
    Timer.stopTimer = function (timerName) {
        var timers = Timer.getTimers();
        if (!timers || !timers[timerName] || timers[timerName].length % 2 === 0) {
            Timer.logger.debug("startTimer : Probl\u00E8me de Timers (" + timerName + ") non d\u00E9marr\u00E9.");
        }
        else {
            timers[timerName].push(new Date().getTime());
            Timer.setTimers(timers);
        }
    };
    /**
     * Arrête tous les timers
     */
    Timer.stopAllTimers = function () {
        var timers = Timer.getTimers();
        if (timers) {
            Object.keys(timers).forEach(function (timerName) {
                if (timers[timerName].length % 2 !== 0) {
                    timers[timerName].push(new Date().getTime());
                }
            });
            Timer.setTimers(timers);
        }
    };
    /**
     * Fonction pour logger les timers se basant sur Timer.TIMERS_ORDER et le cls (hornet.timers)
     * @param {string} url - url à logger
     * @param {integer} statusCode - status http à logger
     */
    Timer.logFinally = function (url, statusCode) {
        var timers = Timer.getTimers();
        var valueTimers = {};
        if (timers) {
            var log_1 = "Metrologie : " + (url || "url unknow") + " - " + (statusCode || "status unknow");
            Timer.TIMERS_ORDER.forEach(function (timer) {
                if (timers[timer]) {
                    if (timers[timer].length % 2 !== 0) {
                        Timer.logger.debug("Probl\u00E8me de Timers (" + timer + ") non stopp\u00E9. Ajout automatique du stop.");
                        timers[timer].push(new Date().getTime());
                    }
                    for (var tCount = 0; tCount < timers[timer].length; tCount += 2) {
                        var tValue = timers[timer][tCount + 1] - timers[timer][tCount];
                        valueTimers[timer] = valueTimers[timer] ? valueTimers[timer] + tValue : tValue;
                    }
                    log_1 += " - " + timer + " " + valueTimers[timer] + " ms";
                }
            });
            Object.keys(timers).filter(function (timerKey) { return this.indexOf(timerKey) - 1; }, Timer.TIMERS_ORDER).sort().forEach(function (timer) {
                if (timers[timer]) {
                    if (timers[timer].length % 2 !== 0) {
                        Timer.logger.debug("Probl\u00E8me de Timers (" + timer + ") non stopp\u00E9. Ajout automatique du stop.");
                        timers[timer].push(new Date().getTime());
                    }
                    for (var tCount = 0; tCount < timers[timer].length; tCount += 2) {
                        var tValue = timers[timer][tCount + 1] - timers[timer][tCount];
                        valueTimers[timer] = valueTimers[timer] ? valueTimers[timer] + tValue : tValue;
                    }
                    log_1 += " - " + timer + " " + valueTimers[timer] + " ms";
                }
            });
            Timer.logger.info(log_1);
        }
        else {
            Timer.logger.warn("No timers available.");
        }
    };
    Timer.getTimers = function (clsKey) {
        if (clsKey === void 0) { clsKey = CLS_KEY; }
        var timers;
        try {
            timers = hornet_js_utils_1.Utils.getCls(clsKey);
        }
        catch (e) {
            Timer.logger.warn("No timers available, Cls error.");
            Timer.logger.debug("error : ", e);
        }
        return timers;
    };
    Timer.setTimers = function (timers, clsKey) {
        if (clsKey === void 0) { clsKey = CLS_KEY; }
        try {
            timers = hornet_js_utils_1.Utils.setCls(clsKey, timers);
        }
        catch (e) {
            Timer.logger.warn("No timers available, Cls error.");
            Timer.logger.debug("error : ", e);
        }
        return timers;
    };
    Timer.TIMER_REQUEST = "REQUEST";
    Timer.TIMER_ACTION = "ACTION";
    Timer.TIMER_SERVICE = "SERVICE";
    Timer.TIMER_AJAX_REQUEST = "REQUEST_AJAX";
    Timer.TIMER_SERVER_HTTP = "HTTP_ROUTER";
    Timer.TIMERS_ORDER = [Timer.TIMER_REQUEST, Timer.TIMER_SERVER_HTTP, Timer.TIMER_ACTION, Timer.TIMER_SERVICE, Timer.TIMER_AJAX_REQUEST];
    Timer.NS_PER_SEC = 1e9;
    Timer.NS_TO_MS_PER_SEC = 1e6;
    Timer.logger = logger_1.Logger.getLogger("hornet-js-core.timers.Timer");
    return Timer;
}());
exports.Timer = Timer;

//# sourceMappingURL=timer.js.map
